@@ -2,14 +2,18 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-VERSION = (0,4,6)
+VERSION = (0,4,7)
+APPLICATION_NAME = "Dynamic Link"
 VERSION_str = str(VERSION).strip('()').replace(',','.').replace(' ','')
-
 VERSION_INFO = """
 Version: %s
-Date: 21.07.2011
+Modification date: 03.08.2011
 
 Hints:
+- 0.4.7 -   - Preesettings can now be overwrite in the presettings.py in the project
+            folder, or directly in the global settings.py, or in a file
+            called dl_settings.py in the same directory as manage.py.
+            - django-dynamic-link now runs with python below version 2.6
 - 0.4.6 -   changes in setup.py to avoid to install the example project.
 - 0.4.5 -   Small adjustments at the example project.
 - 0.4.4 -   1. Because of incomplete setup.py the last distributed package
@@ -23,5 +27,3 @@ Hints:
 TODO:
     - write more unittests
 """ % (VERSION_str,)
-
-APPLICATION_NAME = "Dynamic Link"
\ No newline at end of file
