@@ -5,15 +5,14 @@ from django.views.generic.simple import direct_to_template
 from django.contrib import admin
 admin.autodiscover()
 
-from dynamicLink import dl_settings
+from dynamicLink import presettings
 
 urlpatterns = patterns('',
     # Example:
     (r'^$', direct_to_template, {'template': 'home.html'}),
 
-
     # for django-dynamic-link. By default it catch url/serve/some-dynamic-link/
-    (r'^\w+/%s/' % dl_settings.DOWNLINK_SERVE_PATH, include('dynamicLink.urls')), 
+    (r'^\w+/%s/' % presettings.DYNAMIC_LINK_URL_BASE_COMPONENT, include('dynamicLink.urls')),
 
     # Uncomment the admin/doc line below to enable admin documentation:
     (r'^admin/doc/', include('django.contrib.admindocs.urls')),
